/*
* ldigest.h
* message digest library for Lua based on OpenSSL or Apple CommonDigest
* Luiz Henrique de Figueiredo <lhf@tecgraf.puc-rio.br>
* 01 Apr 2024 08:18:54
* This code is hereby placed in the public domain and also under the MIT license
*/

#ifdef __linux__
#include <openssl/opensslv.h>
#include <openssl/md4.h>
#include <openssl/md5.h>
#include <openssl/sha.h>
#include <openssl/hmac.h>
#define CCHmac(A,k,klen,d,dlen,digest)	\
	HMAC(A,k,klen,(const unsigned char *)d,dlen,digest,NULL)
#define kCCHmacAlgMD2		EVP_md2()
#define kCCHmacAlgMD4		EVP_md4()
#define kCCHmacAlgMD5		EVP_md5()
#define kCCHmacAlgSHA1		EVP_sha1()
#define kCCHmacAlgSHA224	EVP_sha224()
#define kCCHmacAlgSHA256	EVP_sha256()
#define kCCHmacAlgSHA384	EVP_sha384()
#define kCCHmacAlgSHA512	EVP_sha512()
#define AUTHOR		OPENSSL_VERSION_TEXT
#endif

#ifdef __APPLE__
#define COMMON_DIGEST_FOR_OPENSSL
#include <CommonCrypto/CommonDigest.h>
#include <CommonCrypto/CommonHMAC.h>
#define kCCHmacAlgMD2		kCCHmacAlgMD5
#define kCCHmacAlgMD4		kCCHmacAlgMD5
#define AUTHOR		"Apple CommonDigest"
#endif

#if 0
#undef MD2_DIGEST_LENGTH
#undef MD4_DIGEST_LENGTH
#endif

#define SHA1_CTX		SHA_CTX
#define SHA1_DIGEST_LENGTH	SHA_DIGEST_LENGTH
#define SHA224_CTX		SHA256_CTX
#define SHA384_CTX		SHA512_CTX

#ifndef MD2_DIGEST_LENGTH
#define populate_MD2(L,name)
#endif

#ifndef MD4_DIGEST_LENGTH
#define populate_MD4(L,name)
#endif

#ifndef MD5_DIGEST_LENGTH
#define populate_MD5(L,name)
#endif

#ifndef SHA1_DIGEST_LENGTH
#define populate_SHA1(L,name)
#endif

#ifndef SHA224_DIGEST_LENGTH
#define populate_SHA224(L,name)
#endif

#ifndef SHA256_DIGEST_LENGTH
#define populate_SHA256(L,name)
#endif

#ifndef SHA384_DIGEST_LENGTH
#define populate_SHA384(L,name)
#endif

#ifndef SHA512_DIGEST_LENGTH
#define populate_SHA512(L,name)
#endif
